import xarray as xr
import numpy as np

import matplotlib.pyplot as plt

import sys, os
from glob import glob

import shapely
import geopandas
from shapely.geometry import Point, MultiPoint

import time
import pdb

# Build a set of storm track of interest for a given area and time period
# Area of interest is given by maritime area (here Mediterranean Sea)
# Period of interest if driven by Hodges storm tracks



#==================
# Area Of Interest
#==================


# Mediterranean Sea

path = '/home/amouche/data/MASK/iho/'
_file = 'iho.shp'

gpd = geopandas.read_file(path+_file)

polygons = []
for ii in range(len(gpd['name'])):
    popo = gpd['geometry'].iloc[ii]
    popo2 = popo.simplify(0.05, preserve_topology=False)
    polygons.append(popo2)
boundary = geopandas.GeoSeries(shapely.ops.unary_union(polygons))


#==========================================
# Storm Tracks from Reading Univ. (Hodges)
#==========================================

#pathin = '/home/amouche/data/etc_tracks/ERA5_VOR850_1hr_oct-mar20192020_DET/'
#filein = 'ff_trs_pos.addmslp_addwind925_addwind10m.new.nc'
#pathout = pathin

cfiles_in = glob('/home/amouche/data/etc_tracks/*/ff*.nc')

cfiles_in = glob('/home/amouche/data/etc_tracks/ERA5_VOR850_1hr_oct-mar20192020_DET/ff*nc')

for _cf in cfiles_in:

    pathin = os.path.dirname(_cf) + '/'
    filein = os.path.basename(_cf)
    pathout = pathin

    
    print(pathin)
    print(filein)

    ds = xr.open_dataset(pathin+filein)
    #pdb.set_trace()


    for _t in range(len(ds.TRACK_ID)):
    
        _lon = ds.longitude[np.int(ds.FIRST_PT[_t]):np.int(ds.FIRST_PT[_t])+np.int(ds.NUM_PTS[_t])]
        _lat = ds.latitude[np.int(ds.FIRST_PT[_t]):np.int(ds.FIRST_PT[_t])+np.int(ds.NUM_PTS[_t])]
        _spd = ds.wind_speed_10m[np.int(ds.FIRST_PT[_t]):np.int(ds.FIRST_PT[_t])+np.int(ds.NUM_PTS[_t])]
        _lon[_lon>180] = _lon[_lon>180]-360
    
        storm_track = MultiPoint([Point(_lon[uu],_lat[uu]) for uu in range(len(_lon))])

        if (boundary[0].intersects(storm_track)):

            # Select the data of interest
            dss = ds.isel({'record':slice(np.int(ds.FIRST_PT[_t]),np.int(ds.FIRST_PT[_t])+np.int(ds.NUM_PTS[_t]))})

            # Build the name of the file out
            dmin = dss.time.min()#.strftime('%Y.%m.%d')
            dmax = dss.time.max()
            tmin = time.strftime("%Y%m%dT%H%M%S", time.gmtime(dmin.astype(int)/1000000000))
            tmax = time.strftime("%Y%m%dT%H%M%S", time.gmtime(dmax.astype(int)/1000000000))
            fileout = 'storm_track_' + tmin + '_' + tmax + '.nc'
            print(pathout + fileout)
            if os.path.isfile(pathout+fileout):
                print('already done !')
                continue 
            
            # Store the data of interest in output track
            dss.to_netcdf(pathout+fileout)
 


